# Generated by Django 2.2 on 2019-04-30 21:44

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('issuestracker', '0005_issue_dek'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='issue',
            name='order',
        ),
        migrations.AddField(
            model_name='candidate',
            name='active',
            field=models.BooleanField(null=True),
        ),
        migrations.AddField(
            model_name='candidate',
            name='date_exited',
            field=models.DateTimeField(null=True),
        ),
        migrations.AddField(
            model_name='category',
            name='status',
            field=models.CharField(choices=[('draft', 'Draft'), ('live', 'Live')], default='draft', max_length=5),
        ),
        migrations.AddField(
            model_name='issue',
            name='status',
            field=models.CharField(choices=[('draft', 'Draft'), ('live', 'Live')], default='draft', max_length=5),
        ),
    ]
