# Generated by Django 2.2.1 on 2019-05-07 16:07

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('issuestracker', '0010_story_date_added'),
    ]

    operations = [
        migrations.AlterField(
            model_name='story',
            name='date_added',
            field=models.DateField(blank=True, null=True),
        ),
    ]
