# Generated by Django 2.2 on 2019-04-30 15:21

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('issuestracker', '0004_auto_20190429_1423'),
    ]

    operations = [
        migrations.AddField(
            model_name='issue',
            name='dek',
            field=models.TextField(blank=True, null=True),
        ),
    ]
