{% extends "issuestracker/base.html" %}
{% load static %}

{% block api %}
  {{ block.super }}
  <meta name="ISSUE" content="{{ issue }}">
{% endblock %}

{% block styles %}
  {{ block.super }}

  <link rel="stylesheet" href="{% static 'issuestracker/css/main.issue.css' %}">
{% endblock %}

{% block app %}
<script type="text/javascript" src="{% static 'issuestracker/js/main.issue.js' %}"></script>
{% endblock %}
