<nav class="global">
  <div class="header-left bt-icon--house">
    <a href="/">
      <svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" version="1.1" x="0px" y="0px" viewBox="0 0 100 100" enable-background="new 0 0 100 100" xml:space="preserve"><path d="M79.5,81.458h-57V41.27L51,16.729L79.5,41.27V81.458z M25.5,78.458h51V42.646L51,20.688L25.5,42.646V78.458z"></path>
      </svg>
    </a>
  </div>
  <b class="bt-icon bt-icon--politico"></b>
  <a href="{% url 'issuestracker:home' %}" title="POLITICO Datawok" target="_top"><span class="project-name">/ Issues Tracker</span></a>
  <div class="float-right">
    <ul class="nav nav-pills">
      <li class="nav-item">
        <a class="nav-link active" href="{% url 'issuestracker:home' %}"><i class="fas fa-search"></i></a>
      </li>
    </ul>
  </div>
</nav>
