# Generated by Django 2.2 on 2019-04-30 22:02

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('issuestracker', '0006_auto_20190430_2144'),
    ]

    operations = [
        migrations.AlterField(
            model_name='candidate',
            name='date_exited',
            field=models.DateTimeField(blank=True, null=True),
        ),
    ]
