# Generated by Django 2.2 on 2019-04-30 22:03

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('issuestracker', '0007_auto_20190430_2202'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='candidate',
            name='headshot',
        ),
    ]
